/*
 * Vertex2D.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Vertex2D.h"
#include <cmath>

namespace ZoomEdit {
namespace Math {

float Vertex2D::distanceSq(const Vertex2D &v) const {
  return (x - v.x)*(x - v.x) + (y - v.y)*(y - v.y);
}

float Vertex2D::distance(const Vertex2D &v) const {
  return std::sqrt(distanceSq(v));
}

Vector2D Vertex2D::operator-(const Vertex2D &v) const {
  return Vector2D(x - v.x, y - v.y);
}

Vertex2D Vertex2D::operator+(const Vector2D &v) const {
  return Vertex2D(x + v.getX(), y + v.getY());
}

Vertex2D Vertex2D::operator-(const Vector2D &v) const {
  return Vertex2D(x - v.getX(), y - v.getY());
}

Vertex2D& Vertex2D::operator+=(const Vector2D &v) {
  x += v.getX();
  y += v.getY();
  
  return *this;
}

Vertex2D& Vertex2D::operator-=(const Vector2D &v) {
  x -= v.getX();
  y -= v.getY();
  
  return *this;
}

}
}
