/*
 * Vertex2D.h
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMEDIT_MATH_VERTEX2D_H_
#define ZOOMEDIT_MATH_VERTEX2D_H_

#include "Vector2D.h"

namespace ZoomEdit {
namespace Math {

class Vertex2D {
  private:
    float x, y;
    
  public:
    Vertex2D() : x(0), y(0) {}
    Vertex2D(float x0, float y0) : x(x0), y(y0) {}
    
    float getX() const {return x;}
    void setX(float x0) {x = x0;}
    
    float getY() const {return y;}
    void setY(float y0) {y = y0;}
    
    float distanceSq(const Vertex2D &v) const;
    float distance(const Vertex2D &v) const;
    
    Vector2D operator-(const Vertex2D &v) const;
    
    Vertex2D operator+(const Vector2D &v) const;
    Vertex2D operator-(const Vector2D &v) const;
    
    Vertex2D& operator+=(const Vector2D &v);
    Vertex2D& operator-=(const Vector2D &v);
};

}
}

#endif /*ZOOMEDIT_MATH_VERTEX2D_H_*/
